@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# lesspipe.sh, a preprocessor for less (version 2.03)
+# lesspipe.sh, a preprocessor for less (version 2.04)
 # Author: Wolfgang Friebel (wp.friebel AT gmail.com)
 #( [[ -n 1 && -n 2 ]] ) > /dev/null 2>&1 || exec zsh -y --ksh-arrays -- "$0" ${1+"$@"}
 
@@ -289,6 +289,12 @@ get_unpack_cmd () {
 			has_cmd zstd && cmd=(zstd -cdqM1073741824 "$2") && return ;;
 		lz4)
 			has_cmd lz4 && cmd=(lz4 -cdq "$2") && return ;;
+		xlsx)
+			has_cmd in2csv && cmd=(in2csv -f xlsx "$2") && return
+			has_cmd excel2csv && cmd=(istemp excel2csv "$2") && return ;;
+		ms-excel)
+			has_cmd in2csv && cmd=(in2csv -f xls "$2") && return
+			has_cmd xls2csv && cmd=(istemp xls2csv "$2") && return ;;
 	esac
 	# convert into utf8
 
@@ -443,7 +449,8 @@ isfinal () {
 			# filename needs to end in .class
 			has_cmd procyon && t=$t.class && cat "$1" > $t && cmd=(procyon "$t") ;;
 		markdown)
-			{ has_cmd mdcat && cmd=(mdcat "$1"); } ||
+			[[ $COLOR = *always ]] && mdopt= || mdopt=-c
+			{ has_cmd mdcat && cmd=(mdcat $mdopt "$1"); } ||
 			{ has_cmd pandoc && cmd=(pandoc -t plain "$1"); } ;;
 		docx)
 			{ has_cmd pandoc && cmd=(pandoc -f docx -t plain "$1"); } ||
@@ -457,9 +464,7 @@ isfinal () {
 					-o $t2" "$1" && cmd=(pandoc -f markdown -t plain "$t2"); }; } ||
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" ppt); } ;;
 		xlsx)
-			{ has_cmd in2csv && cmd=(in2csv -f xlsx "$1"); } ||
 			{ has_cmd xlscat && cmd=(istemp xlscat "$1"); } ||
-			{ has_cmd excel2csv && cmd=(istemp excel2csv "$1"); } ||
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" xlsx); } ;;
 		odt)
 			{ has_cmd pandoc && cmd=(pandoc -f odt -t plain "$1"); } ||
@@ -480,8 +485,6 @@ isfinal () {
 			{ has_cmd broken_catppt && cmd=(istemp catppt "$1"); } ||
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" ppt); } ;;
 		ms-excel)
-			{ has_cmd in2csv && cmd=(in2csv -f xls "$1"); } ||
-			{ has_cmd xls2csv && cmd=(istemp xls2csv "$1"); } ||
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" xls); } ;;
 		ooffice1)
 			{ has_cmd sxw2txt && cmd=(istemp sxw2txt "$1"); } ||
@@ -527,8 +530,11 @@ isfinal () {
 		mp3)
 			has_cmd id3v2 && cmd=(istemp "id3v2 --list" "$1") ;;
 		log)
-			has_cmd ccze && cat "$1" | ccze -A
+			has_cmd ccze && [[ $COLOR = *always ]] && cat "$1" | ccze -A
 			return ;;
+		csv)
+			{ has_cmd csvlook && cmd=(csvlook "$1"); } ||
+			{ has_cmd pandoc && cmd=(pandoc -f csv -t plain "$1"); } ;;
 	esac
 	fi
 	# not a specific file format
@@ -750,11 +756,10 @@ if [[ -z "$1" ]]; then
 		echo "export LESSOPEN"
 	fi
 else
-	if [ -x ~/.lessfilter ]; then
-		~/.lessfilter "$1"
-		if [ $? -eq 0 ]; then
-			exit 0
-		fi
+	if [ -x "${HOME}/.lessfilter" ]; then
+		"${HOME}/.lessfilter" "$1" && exit 0
+	elif has_cmd lessfilter; then
+		lessfilter "$1" && exit 0
 	fi
 	show "$@"
 fi
