@@ -8,7 +8,7 @@ use Archive::Tar;
 
 # do a clean up if we get a CTRL-C
 our $tdir;
-$SIG{INT} = sub  { if ($tdir) {unlink $tdir; print "\n"; exit 1 }};
+$SIG{INT} = sub { if ($tdir) {unlink $tdir; print "\n"; exit 1 }};
 
 sub usage {
 	print <<EOF;
@@ -182,13 +182,17 @@ sub comp {
 	chomp $comp;
 	my $ok = '';
 	my $reset = color('reset');
-	if ($comp =~ s/^= //) {
-		# ignore leading and trailing newlines, unicode start of file
+	# ignore unicode start of file
+	$res =~ s/^\x{fe}\x{ff}//;
+	$res =~ s/^\x{ef}\x{bb}\x{bf}//;
+	if ($comp =~ /^= ?/) {
+		$comp =~ s/^= ?//;
+		# ignore leading and trailing newlines
 		$res =~ s/^\n//g;
 		$res =~ s/\0//g;
 		$res =~ s/\014//g;
 		$res =~ s/\r?\n$//g;
-		$res =~ s/^\x{ef}\x{bb}\x{bf}//;
+		return 'ok' if $res eq $comp;
 		for (split /\|/, $comp) {
 			return 'ok' if $res eq $_;
 		}
@@ -284,10 +288,6 @@ less $T/tests/test_7z:testok/a\|b.txt	# extract file from 7z, needs 7zr|7za
 = test
 less tests/archive.tgz:test_7z:testok/a\|b.txt	# (on the fly), needs 7zr|7za
 = test
-less $T/tests/test_1file_7za		# extract the only file from 7z, needs 7zr|7za
-= test
-less tests/archive.tgz:test_1file_7za	# (on the fly), needs 7zr|7za
-= test
 less $T/tests/test_iso			# iso9660 contents, needs bsdtar
 ~ .* ISO.TXT
 less tests/archive.tgz:test_iso		# (on the fly), needs bsdtar
@@ -337,7 +337,7 @@ less tests/filter.tgz:test_latin1	# ISO-8859-1 encoded file  needs iconv
 less $T/tests/test_plain			# plain text, no output from lesspipe.sh
 = test=a
 less tests/filter.tgz:test_html		# html text, needs html_converter
-= test
+~ \s*test
 less tests/filter.tgz:test_html:	# html unmodified text
 ~ </head>
 less tests/filter.tgz:test_pdf		# pdf, needs pdftotext|pdftohtml,html_converter|pdfinfo
@@ -355,13 +355,13 @@ less tests/filter.tgz:test_xlsx		# xlsx (neu), needs in2csv|xlscat|excel2csv|lib
 less tests/filter.tgz:test_odt		# odt, needs pandoc|odt2txt|libreoffice
 = test
 less tests/filter.tgz:test_odp		# odp, needs libreoffice,html_converter
-~ test
+~ \s*test
 less tests/filter.tgz:test_ods		# ods, needs xlscat|libreoffice,html_converter
 ~ test
 less tests/filter.tgz:test_doc		# doc (old), needs wvText|antiword|catdoc|libreoffice
 ~  *test
 less tests/filter.tgz:test_ppt:ms-powerpoint	# ppt (old), catppt not always working, needs libreoffice,html_converter
-~ .*1. test
+~ .*1. test|\s*test
 less tests/filter.tgz:test_xls		# xls (old), needs in2csv|xls2csv|libreoffice,html_converter
 = test
 less tests/filter.tgz:test_ooffice1	# openoffice1 (very old), needs sxw2txt|libreoffice
@@ -376,12 +376,14 @@ less tests/filter.tgz:test_so		# shared library (.so)
 ~ .* T test
 less tests/filter.tgz:test.pod		# pod text, needs pod2text|perldoc
 ~     test
+less tests/filter.tgz:test.pod		# perl storable, needs perl
+~     test
 less tests/filter.tgz:test.pod:		# unmodified pod text, needs pod2text|perldoct
 ~ test
 less tests/filter.tgz:test_nc4		# netcdf, needs h5dump|ncdump
-~ data:
+~ data:|\s*DATA .
 less tests/filter.tgz:test_nc5		# hierarchical data format, needs h5dump|ncdump
-~ data:
+~ d:|\s*DATA .
 less tests/filter.tgz:test_matlab	# matlab git #18, needs matdump
 ~ r
 less tests/filter.tgz:matlab.mat	# matlab, not recognized by file, needs matdump
@@ -424,15 +426,21 @@ less tests/filter.tgz:index.rst		# Jupyter notebook to rst git #6, needs mdcat|p
 c # test
 less tests/filter.tgz:test.json		# json, epub and ipynb also covered git #62 (fails if no syntax/json.vim), needs pandoc
 c false
-less tests/filter.tgz:t.eclass		# ebuild and eclass file git #9,38,39
+LESSCOLORIZER=code2color less tests/filter.tgz:t.eclass		# ebuild and eclass file git #9,38,39
 c test
 less tests/filter.tgz:Makefile		# bsd Makefile not (file 5.28) / is (5.39) correctly recognized git #10
 c PORTNAME
 diff -u $T/tests/t.eclass $T/tests/test.c|less - :diff # unified diff piped through less works git #11
 c test=a
 ### github issues (solved and unsolved) and other test cases
+LESSCOLORIZER=code2color less tests/special.tgz:a-r-R.pl	# colorize works within archives
+c sub
+less $T/tests/a-r-R.pl		# do not call vimcolor with -l extension git #77
+c sub
+LESS= less $T/tests/a-r-R.pl		# name contains -r or -R git #78
+= sub test {}
 less $T/tests/test_zip:non-existent-file	# nonexisting file in a zip archive git issue #1
-~ .* non-existent-file.*
+= 
 less $T/tests/test\ \;\'\"\[\(\{ok		# file name with chars such as ", ' ...
 = test
 less tests/special.tgz:test\ \;\'\"\[\(\{ok	# archive having a file with chars from [ ;"'] etc. in the name
@@ -466,4 +474,4 @@ less $T/tests/test_plain :			# even watch growing files without +F
 less $T/tests/test.jar			# support for jar files git #8,22
 ~ .* META-INF/
 ###    .lessfilter not implemented git #23 (open)
-###    markdown files (mdcat) on MacOSX and iTerm2 without color git #48 (open)
+###    colorize markdown files (mdcat) on MacOSX and iTerm2 (see git #48)
